==> foundation-core-app-1.6.1-1216-v2.2.tgz: package/common/hero/variants/three-cards/HeroCard.tsx <==
import {
    memo,
    useMemo,
} from 'react';

import Box from '@mui/material/Box';
import {
    NsTypography,
    Show,
    Variants,
} from '@nuskin/foundation-ui-components';

import { BynderImage } from '../../../bynder-image/BynderImage';
import NsCTALinkComponent from '../../../cta-link/CtaLink';
import { useRouteReplacer } from '../../../hooks';
import useToggleFontColor from '../../../hooks/use-toggle-font-color/useToggleFontColor';
import { getBasicDATWidthHeight } from '../../../utils/bynder-util';
import { HeroCardProps } from '../../types/types';
import {
    ContentContainer,
    ImageContainer,
    TextContainer,
} from './ThreeCards.styled';

const PanelTypographyVariantMap: {
    [key: string]: {
        preHeaderVariant: Variants;
        headerVariant: Variants;
        descriptionVariant: Variants;
    };
} = {
    main: {
        preHeaderVariant: 'h4',
        headerVariant: 'h1',
        descriptionVariant: 'h3',
    },
    sub: {
        preHeaderVariant: 'body-m',
        headerVariant: 'h2',
        descriptionVariant: 'body-l',
    },
};

/**
 * Hero card specifically for Three cards component. This is a memod component.
 * TODO: we can move this out if it can be reused. Rename it appropriately.
 */
const suffix = getBasicDATWidthHeight(900, 480, 'scale');
const HeroCard = memo((props: HeroCardProps & { isMain?: boolean }) => {
    const {
        preHeader,
        header,
        description,
        fontColor,
        backgroundColor,
        backgroundScrim,
        image,
        callToAction,
        renderH1 = false,
        liveTags,
        dataTestId = 'hero-card',
        isMain,
        $,
    } = props;

    const { url } = callToAction || {};
    const { url: sanitizedUrl = '' } = useRouteReplacer(url);

    const { preHeaderVariant, headerVariant, descriptionVariant } = PanelTypographyVariantMap[isMain ? 'main' : 'sub'];

    const resolvedFontColor = useToggleFontColor(fontColor);

    const imageSection = useMemo(
        () => (
            <ImageContainer>
                <BynderImage
                    liveTag={$?.image ?? { 'data-cslp': '' }}
                    imageText={image}
                    suffix={suffix}
                    className="three-card-hero-image"
                />
            </ImageContainer>
        ),
        [$?.image, image]
    );

    const textSection = useMemo(
        () => (
            <TextContainer>
                <Box sx={{ overflow: 'hidden', height: '100%' }}>
                    <Show when={!!preHeader}>
                        <NsTypography
                            variant={preHeaderVariant}
                            colorOverride={resolvedFontColor}
                            additionalProps={{
                                'data-testid': 'pre-header',
                                ...liveTags?.preHeader,
                            }}
                            noSpacing
                        >
                            {preHeader}
                        </NsTypography>
                    </Show>
                    <Show when={!!header}>
                        <NsTypography
                            variant={headerVariant}
                            renderHTMLNode={renderH1}
                            colorOverride={resolvedFontColor}
                            additionalProps={{
                                'data-testid': 'header',
                                ...liveTags?.header,
                            }}
                        >
                            {header}
                        </NsTypography>
                    </Show>
                    <Show when={!!description}>
                        <NsTypography
                            variant={descriptionVariant}
                            colorOverride={resolvedFontColor}
                            additionalProps={{
                                'data-testid': 'description',
                                ...liveTags?.description,
                            }}
                        >
                            {description}
                        </NsTypography>
                    </Show>
                    <NsCTALinkComponent ctaProps={callToAction} liveTag={liveTags?.callToAction} />
                </Box>
            </TextContainer>
        ),
        [
            callToAction,
            description,
            descriptionVariant,
            header,
            headerVariant,
            liveTags?.callToAction,
            liveTags?.description,
            liveTags?.header,
            liveTags?.preHeader,
            preHeader,
            preHeaderVariant,
            renderH1,
            resolvedFontColor,
        ]
    );

    const content = useMemo(() => {
        return (
            <ContentContainer
                backgroundColor={backgroundColor}
                onClick={() => (sanitizedUrl ? window.open(sanitizedUrl, '_blank') : null)}
            >
                {imageSection}
                {textSection}
            </ContentContainer>
        );
    }, [backgroundColor, imageSection, textSection, sanitizedUrl]);

    return (
        <div
            className={`hero-card ${isMain ? 'main-card' : 'sub-card'} ${backgroundScrim ? 'with-scrim' : ''}`}
            data-testid={dataTestId}
        >
            {content}
        </div>
    );
});

HeroCard.displayName = 'HeroCard';

export default HeroCard;

==> foundation-core-app-1.8.0-1216-v2.1.tgz: package/common/hero/variants/three-cards/HeroCard.tsx <==
import { memo, useMemo } from 'react';

import Box from '@mui/material/Box';
import { NsTypography, Show, Variants } from '@nuskin/foundation-ui-components';

import { BynderImage } from '../../../bynder-image/BynderImage';
import NsCTALinkComponent from '../../../cta-link/CtaLink';
import { useRouteReplacer } from '../../../hooks';
import useToggleFontColor from '../../../hooks/use-toggle-font-color/useToggleFontColor';
import { getBasicDATWidthHeight } from '../../../utils/bynder-util';
import { HeroCardProps } from '../../types/types';
import { ContentContainer, ImageContainer, TextContainer } from './ThreeCards.styled';

const PanelTypographyVariantMap: {
    [key: string]: {
        preHeaderVariant: Variants;
        headerVariant: Variants;
        descriptionVariant: Variants;
    };
} = {
    main: {
        preHeaderVariant: 'h4',
        headerVariant: 'h1',
        descriptionVariant: 'h3'
    },
    sub: {
        preHeaderVariant: 'body-m',
        headerVariant: 'h2',
        descriptionVariant: 'body-l'
    }
};

/**
 * Hero card specifically for Three cards component. This is a memod component.
 * TODO: we can move this out if it can be reused. Rename it appropriately.
 */
const suffix = getBasicDATWidthHeight(900, 480, 'scale');
const HeroCard = memo((props: HeroCardProps & { isMain?: boolean }) => {
    const {
        preHeader,
        header,
        description,
        fontColor,
        backgroundColor,
        backgroundScrim,
        image,
        callToAction,
        renderH1 = false,
        liveTags,
        dataTestId = 'hero-card',
        isMain,
        $
    } = props;

    const { url } = callToAction || {};
    const { url: sanitizedUrl = '' } = useRouteReplacer(url);

    const { preHeaderVariant, headerVariant, descriptionVariant } = PanelTypographyVariantMap[isMain ? 'main' : 'sub'];

    const resolvedFontColor = useToggleFontColor(fontColor);

    const imageSection = useMemo(
        () => (
            <ImageContainer>
                <BynderImage
                    liveTag={$?.image ?? { 'data-cslp': '' }}
                    imageText={image}
                    suffix={suffix}
                    className="three-card-hero-image"
                />
            </ImageContainer>
        ),
        [$?.image, image]
    );

    const textSection = useMemo(
        () => (
            <TextContainer>
                <Box sx={{ overflow: 'hidden', height: '100%' }}>
                    <Show when={!!preHeader}>
                        <NsTypography
                            variant={preHeaderVariant}
                            colorOverride={resolvedFontColor}
                            additionalProps={{
                                'data-testid': 'pre-header',
                                ...liveTags?.preHeader
                            }}
                            noSpacing
                        >
                            {preHeader}
                        </NsTypography>
                    </Show>
                    <Show when={!!header}>
                        <NsTypography
                            variant={headerVariant}
                            renderHTMLNode={renderH1}
                            colorOverride={resolvedFontColor}
                            additionalProps={{
                                'data-testid': 'header',
                                ...liveTags?.header
                            }}
                        >
                            {header}
                        </NsTypography>
                    </Show>
                    <Show when={!!description}>
                        <NsTypography
                            variant={descriptionVariant}
                            colorOverride={resolvedFontColor}
                            additionalProps={{
                                'data-testid': 'description',
                                ...liveTags?.description
                            }}
                        >
                            {description}
                        </NsTypography>
                    </Show>
                    <NsCTALinkComponent ctaProps={callToAction} liveTag={liveTags?.callToAction} />
                </Box>
            </TextContainer>
        ),
        [
            callToAction,
            description,
            descriptionVariant,
            header,
            headerVariant,
            liveTags?.callToAction,
            liveTags?.description,
            liveTags?.header,
            liveTags?.preHeader,
            preHeader,
            preHeaderVariant,
            renderH1,
            resolvedFontColor
        ]
    );

    const content = useMemo(() => {
        return (
            <ContentContainer
                backgroundColor={backgroundColor}
                onClick={() => (sanitizedUrl ? window.open(sanitizedUrl, '_blank') : null)}
            >
                {imageSection}
                {textSection}
            </ContentContainer>
        );
    }, [backgroundColor, imageSection, textSection, sanitizedUrl]);

    return (
        <div
            className={`hero-card ${isMain ? 'main-card' : 'sub-card'} ${backgroundScrim ? 'with-scrim' : ''}`}
            data-testid={dataTestId}
        >
            {content}
        </div>
    );
});

HeroCard.displayName = 'HeroCard';

export default HeroCard;
